# oranchada
Orange workflow add-on with ramanchada2 functionality


https://github.com/biolab/orange3-example-addon
https://orange3.readthedocs.io/projects/orange-development/en/latest/tutorial.html#defining-a-widget

For developers
--------------

If you would like to install from cloned git repository, run

    pip install .

To register this add-on with Orange, but keep the code in the development
directory (do not copy it to Python's site-packages directory), run

    pip install -e .

Further details can be found in [CONTRIBUTING.md](CONTRIBUTING.md)

---
🇪🇺 This project has received funding from the European Union’s Horizon 2020 research and innovation program under [grant agreement No. 952921](https://cordis.europa.eu/project/id/952921).
